@@ -382,18 +382,18 @@ def set_cross_file_variable(key_val: List[tuple]) -> bool:
     :return:
     """
     if type(key_val) != list:
-        log(string="全局变量设置错误，请提供List类型并且保证所有元素都是tuple", print_file=sys.stderr)
+        log("全局变量设置错误，请提供List类型并且保证所有元素都是tuple", print_file=sys.stderr)
         return False
     for k_v in key_val:
         if type(k_v) != tuple:
-            log(string="全局变量设置错误，请提供List类型并且保证所有元素都是tuple", print_file=sys.stderr)
+            log("全局变量设置错误，请提供List类型并且保证所有元素都是tuple", print_file=sys.stderr)
             return False
     global_val._init()
     for k_v in key_val:
         try:
             global_val.set_value(k_v[0], k_v[1])
         except Exception as e:
-            log(string="设置全局跨文件变量{}错误：{}".format(k_v, e), print_file=sys.stderr)
+            log("设置全局跨文件变量{}错误：{}".format(k_v, e), print_file=sys.stderr)
             return False
     return True
 
@@ -406,7 +406,7 @@ def is_ip(proxy_test: str = "") -> bool:
     """
     flag = False
     if type(proxy_test) != str:
-        log(string="参数{}不是字符串".format(proxy_test), print_file=sys.stderr)
+        log("参数{}不是字符串".format(proxy_test), print_file=sys.stderr)
         return False
     if len(proxy_test) == 0:
         return flag
@@ -426,10 +426,10 @@ def stop_thread(thread_list: List[CanStopThread] = []) -> int:
         try:
             t.stop()
         except ThreadStopException as e:
-            log(string="线程{}结束".format(t.name), print_file=sys.stderr)
+            log("线程{}结束".format(t.name), print_file=sys.stderr)
             count = count + 1
         except Exception as e:
-            log(string="结束线程{}错误{}".format(t.name, e), print_file=sys.stderr)
+            log("结束线程{}错误{}".format(t.name, e), print_file=sys.stderr)
     return count
 
 
@@ -557,7 +557,7 @@ def basic_config(log_file_name: str = "crawler_util.log",
                 s.setDaemon(set_daemon)
                 s.start()
         except Exception as e:
-            log(string="proxypool线程异常{}".format(e), print_file=sys.stderr)
+            log("proxypool线程异常{}".format(e), print_file=sys.stderr)
         proxy_test = ""
         url = HTTP + api_host + COLON_SEPARATOR + str(api_port) + "/random"
         is_ip_flag = False
@@ -568,7 +568,7 @@ def basic_config(log_file_name: str = "crawler_util.log",
                     proxy_test = requests.get(url, timeout=(20, 20)).text
                     is_ip_flag = is_ip(proxy_test)
                 except Exception as e:
-                    log(string="测试proxypool项目报错:{}".format(e), print_file=sys.stderr)
+                    log("测试proxypool项目报错:{}".format(e), print_file=sys.stderr)
                     proxy_test = ""
                 time.sleep(2)
             if len(proxy_pool_url) == 0:
@@ -578,10 +578,10 @@ def basic_config(log_file_name: str = "crawler_util.log",
         return s, g, t
     else:
         if require_proxy_pool and PROXY_POOL_CAN_RUN_FLAG:
-            log(string="redis或者Flask配置错误", print_file=sys.stderr)
+            log("redis或者Flask配置错误", print_file=sys.stderr)
             return ()
         elif require_proxy_pool and not PROXY_POOL_CAN_RUN_FLAG:
-            log(string="无法重复启动proxypool")
+            log("无法重复启动proxypool")
             return ()
         elif not require_proxy_pool:
             return ()
@@ -609,15 +609,15 @@ def get_proxy() -> str or None:
     :return:
     """
     if len(PROXY_POOL_URL) <= 0:
-        log(string="使用了代理（require_proxy=Ture）,但是没有设置代理连接", print_file=sys.stderr)
-        log(string="请使用basic_config(proxy_pool_url=\"\")设置", print_file=sys.stderr)
+        log("使用了代理（require_proxy=Ture）,但是没有设置代理连接", print_file=sys.stderr)
+        log("请使用basic_config(proxy_pool_url=\"\")设置", print_file=sys.stderr)
         raise Exception("无法获取代理连接")
     try:
         response = requests.get(PROXY_POOL_URL)
         if response.status_code == 200:
             return response.text
     except ConnectionError as e:
-        log(string=e, print_file=sys.stderr)
+        log(e, print_file=sys.stderr)
         return None
 
 
@@ -633,7 +633,7 @@ def two_one_choose(p: int = 0.5) -> bool:
         return False
 
 
-def local_path_generate(folder_name: str, file_name: str = "",
+def local_path_generate(folder_name: str = "", file_name: str = "",
                         suffix: str = ".pdf", need_log: bool = True,
                         create_folder_only: bool = False) -> str:
     """
@@ -655,7 +655,7 @@ def local_path_generate(folder_name: str, file_name: str = "",
         else:
             os.makedirs(folder_name)
     except Exception as e:
-        log(string="创建文件夹{}失败".format(e), print_file=sys.stderr)
+        log("创建文件夹{}失败".format(e), print_file=sys.stderr)
         return ""
     if create_folder_only:
         return os.path.abspath(folder_name)
@@ -687,7 +687,7 @@ def write_file(path: str, mode: str, string: str, encoding: str = "utf-8") -> bo
         log("写入文件{}成功".format(path))
         return True
     except Exception as e:
-        log(string="写入文件{}失败：{}".format(path, e), print_file=sys.stderr)
+        log("写入文件{}失败：{}".format(path, e), print_file=sys.stderr)
         return False
 
 
@@ -834,12 +834,12 @@ def getAllFiles(target_dir: str) -> list:
     """
     files = []
     if len(target_dir) == 0:
-        log(string="文件路径为空", print_file=sys.stderr)
+        log("文件路径为空", print_file=sys.stderr)
         return files
     try:
         listFiles = os.listdir(target_dir)
     except Exception as e:
-        log(string="打开文件夹{}异常：{}".format(target_dir, e), print_file=sys.stderr)
+        log("打开文件夹{}异常：{}".format(target_dir, e), print_file=sys.stderr)
         return files
     for i in range(0, len(listFiles)):
         path = os.path.join(target_dir, listFiles[i])
