@@ -16,6 +16,191 @@ from PaperCrawlerUtil.office_util import *
 import pymysql
 
 
+class DB_util(object):
+
+    def __init__(self, **db_conf) -> None:
+        super().__init__()
+        self.conn = None
+        self.cursor = None
+        self.ssl = None
+        if len(db_conf) <= 0:
+            log("需要配置字典", print_file=sys.stderr)
+            return None
+        check_ssl = True if db_conf.get("ssl_ip") is not None and db_conf.get("ssl_admin") is not None and \
+                            db_conf.get("ssl_pwd") is not None and db_conf.get("ssl_db_port") is not None \
+                            and db_conf.get("ssl_port") is not None else False
+        if check_ssl:
+            self.ssl = SSHTunnelForwarder(
+                ssh_address_or_host=(db_conf.get("ssl_ip"), db_conf.get("ssl_port")),
+                ssh_username=db_conf.get("ssl_admin"),
+                ssh_password=db_conf.get("ssl_pwd"),
+                remote_bind_address=('localhost', db_conf.get("ssl_db_port"))
+            )
+            self.ssl.start()
+        self.db_url = "127.0.0.1" if check_ssl else db_conf.get("db_url")
+        self.db_username = db_conf.get("db_username")
+        self.db_pass = db_conf.get("pass")
+        self.port = self.ssl.local_bind_port if check_ssl else db_conf.get("port")
+        self.db_database = db_conf.get("db_database") if db_conf.get("db_database") is not None else "research"
+        self.db_table = db_conf.get("db_table") if db_conf.get("db_table") is not None else "record_result"
+        self.db_field = db_conf.get("db_field") if db_conf.get("db_field") is not None \
+            else ["id", "file_execute", "execute_time", "finish_time", "result", "args", "other", "delete_flag"]
+        self.db_type = db_conf.get("db_type") if db_conf.get("db_type") is not None else "mysql"
+
+        self.ignore_error = db_conf.get("ignore_error") if db_conf.get("ignore_error") is not None else True
+        try:
+            self.create_db_conn()
+            self.cursor = self.conn.cursor()
+        except Exception as e:
+            log("链接数据库失败，请修改配置，云服务器请配置ssl：{}".format(e))
+
+    def generate_sql(self, kvs: Dict = None, op_type: str = OP_TYPE[3],
+                     condition: Dict[Tuple[str, int or float or str or Tuple], str] = None,
+                     limit: int = 100) -> str:
+        """
+        根据给定的值生成简单的sql，其中select语句最难生成，因此只能是给个参考，慎用本方法生成select语句
+        :param condition:键值对，键是元组，长度为两个元素，值是条件参数，例如：
+        {("dass", 231): "="}，代码会转换为“dass” = 231 作为条件加入where语句
+        :param limit:select 语句中防止查询过大，默认100
+        :param kvs:修改，增加时，需要给定该参数，指示需要修改或新增行时的参数，例如
+            {"id": 2, "file_execute": "file", "execute_time": "2022年11月1日21:24:58"}，代码会将之转换为如下：
+
+            INSERT INTO `research`.`record_result` (`id`, `file_execute`, `execute_time`)
+            VALUES (2, "file", "2022年11月1日21:24:58");
+
+            UPDATE `research`.`record_result` SET `id` = 2, `file_execute` = "file",
+            `execute_time` = "2022年11月1日21:24:58";
+
+            SELECT `id`, `file_execute`, `execute_time` FROM `research`.`record_result`;
+
+        :param op_type: 取值为["INSERT", "UPDATE", "DELETE", "SELECT"]，指明生成的sql类型
+        :return:生成的sql
+        """
+        fields = []
+        values = []
+        condition_clause = "WHERE "
+        if op_type == OP_TYPE[3] and (kvs is None or len(kvs) == 0):
+            fields = "*"
+        else:
+            for kv in kvs.items():
+                fields.append("`" + str(kv[0]) + "`")
+                t = type(kv[1])
+                if t == int or t == float:
+                    values.append(str(kv[1]))
+                else:
+                    values.append("\"" + str(kv[1]) + "\"")
+        if condition is None or len(condition) == 0:
+            condition_clause = ""
+        else:
+            count = 0
+            for kv in condition.items():
+                t = type(kv[0][1])
+                if t == int or t == float:
+                    condition_clause = condition_clause + str(kv[0][0]) + " " + str(kv[1]) + " " + str(kv[0][1])
+                elif t == tuple:
+                    tuple_str = str(kv[0][1]) if len(kv[0][1]) > 1 else str(kv[0][1]).replace(",", "")
+                    condition_clause = condition_clause + str(kv[0][0]) + " " + str(kv[1]) + " " + tuple_str
+                elif t == str:
+                    condition_clause = condition_clause + \
+                                       str(kv[0][0]) + " " + str(kv[1]) + " " + "\"" + str(kv[0][1]) + "\""
+                if count < len(condition) - 1:
+                    condition_clause = condition_clause + " AND "
+                count = count + 1
+        if op_type not in OP_TYPE:
+            op_type = OP_TYPE[3]
+        if op_type == OP_TYPE[0]:
+            sql = "INSERT INTO `" + self.db_database + "`.`" + self.db_table + "` ({})" + " VALUES ({});"
+            sql = sql.format(", ".join(fields), ", ".join(values))
+        elif op_type == OP_TYPE[1]:
+            sql = "UPDATE `" + self.db_database + "`.`" + self.db_table + "` SET {} {};"
+            modify = ""
+            for i in range(len(fields)):
+                modify = modify + fields[i] + " = " + values[i]
+                if i < len(fields) - 1:
+                    modify = modify + ", "
+            sql = sql.format(modify, condition_clause)
+        elif op_type == OP_TYPE[2]:
+            sql = "DELETE FROM `" + self.db_database + "`.`" + self.db_table + "` {};"
+            sql = sql.format(condition_clause)
+        elif op_type == OP_TYPE[3]:
+            sql = "SELECT" + " {} ".format(
+                ", ".join(fields)) + "FROM `" + self.db_database + "`.`" + self.db_table + "` {} LIMIT {};". \
+                      format(condition_clause, str(limit))
+        return sql
+
+    def create_db_conn(self):
+        """
+        链接数据库，不返回链接，全局使用一个连接conn
+        :return:
+        """
+        connection = pymysql.connect(host=self.db_url,
+                                     user=self.db_username,
+                                     password=self.db_pass,
+                                     db=self.db_database,
+                                     port=self.port,
+                                     charset="utf8"
+                                     )
+        self.conn = connection
+        self.conn.autocommit(True)
+
+    def execute(self, sql: str) -> bool:
+        """
+        内部方法，执行sql
+        也可以执行用户自定义的sql，比如利用建表时默认的四个默认列记录数据等
+        :param sql: 待执行的sql
+        :return:
+        """
+        try:
+            self.cursor.execute(sql)
+            return True
+        except Exception as e:
+            log("执行失败：{}".format(e))
+            if self.ignore_error:
+                write_file(local_path_generate("", "record_error.log"), mode="a+", string=sql + "\n")
+            return False
+
+    def select_one(self, condition: Dict) -> List:
+        """
+        查询一个记录
+        :param condition:条件字典，形如{("a", "b") : "="} 即 where a = b，或者{"a":"b"},后台会自动将后一种形式转换为前一种，
+        但是，二者的关系只能是"="，即后面一种形式是前一种形式的特定情况简化版。
+        :return:
+        """
+        sql = self.generate_sql(condition=condition, op_type=SELECT)
+        if self.execute(sql):
+            return self.cursor.fetchone()
+        else:
+            return []
+
+    def select_page(self, condition: Dict, limit: int = 100) -> List[List]:
+        return []
+
+    def insert_one(self, kvs: Dict or List) -> bool:
+        return True
+
+    def update(self, condition: Dict) -> bool:
+        return True
+
+    def delete(self, condition: Dict) -> bool:
+        return True
+
+    def export(self, condition: Dict) -> bool:
+        return True
+
+    def __del__(self):
+        """
+        关闭连接，不知道为什么调用的时候加（）会报错，比如self.ssl.stop（），会报错
+        TypeError: 'NoneType' object is not callable
+        :return:
+        """
+        if self.ssl is not None:
+            self.ssl.stop
+        if self.conn is not None:
+            self.conn.close
+        if self.cursor is not None:
+            self.cursor.close
+
+
 class ResearchRecord(object):
     """
     通过在程序中调用该对象方法，在数据库中记录参数，运行的文件， 运行的时间等信息
@@ -398,6 +583,22 @@ class ResearchRecord(object):
         else:
             return False
 
+    def get_by_id(self, data: Dict) -> List:
+        """
+        根据id获取信息
+        :param data:
+        :return:
+        """
+        try:
+            id = data["id"]
+        except Exception as e:
+            log("请提供id，{}".format(e))
+        sql = self.generate_sql(condition={("id", id): "="}, op_type=SELECT)
+        if self._execute(sql):
+            return list(self.cursor.fetchone())
+        else:
+            return []
+
     def __del__(self):
         """
         关闭连接，不知道为什么调用的时候加（）会报错，比如self.ssl.stop（），会报错
@@ -414,3 +615,4 @@ class ResearchRecord(object):
 
 if __name__ == "__main__":
     basic_config(logs_style=LOG_STYLE_PRINT)
+
